Issue

Struct Issue 

pub struct Issue { /* private fields */ }
Evidence-backed data-quality issue attached to source records and derived facts.

Implementations

Source

impl Issue

pub fn new( kind: Kind, severity: Severity, provenance: Provenance, detected_at: Timestamp, workflow_blocking: bool, ) -> Self

Creates an open data-quality issue from provenance and validated issue metadata.

pub fn kind(&self) -> Kind

Returns the kind for this data quality value.

pub const fn severity(&self) -> Severity

Returns this data quality value’s severity.

pub const fn source_system(&self) -> System

Returns this data quality value’s source system.

pub const fn source_record_ref(&self) -> &RecordRef

Returns this data quality value’s source record ref.

pub const fn provenance(&self) -> &Provenance

Returns this data quality value’s provenance.

pub const fn detected_at(&self) -> &Timestamp

Returns this data quality value’s detected at.

pub const fn resolution_status(&self) -> ResolutionStatus

Returns this data quality value’s resolution status.

pub const fn visible_to_bi(&self) -> bool

Returns this data quality value’s visible to bi.

pub const fn workflow_blocking(&self) -> bool

Returns whether this issue must stop automation or projection into labor workflows.